
.. image:: https://codecov.io/gh/muhrin/minkipy/branch/develop/graph/badge.svg
    :target: https://codecov.io/gh/muhrin/minkipy
    :alt: Coverage

.. image:: https://travis-ci.com/muhrin/minkipy.svg?branch=master
    :target: https://travis-ci.com/github/muhrin/minkipy
    :alt: Travis CI

.. image:: https://img.shields.io/pypi/v/minkipy.svg
    :target: https://pypi.python.org/pypi/minkipy/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/wheel/minkipy.svg
    :target: https://pypi.python.org/pypi/minkipy/

.. image:: https://img.shields.io/pypi/pyversions/minkipy.svg
    :target: https://pypi.python.org/pypi/minkipy/

.. image:: https://img.shields.io/pypi/l/minkipy.svg
    :target: https://pypi.python.org/pypi/minkipy/

minkiPy
=======

.. image:: docs/source/img/mincepy.svg
   :height: 64px
   :width: 64px
   :alt: mincePy
   :target: https://travis-ci.com/github/muhrin/minkipy

.. image:: docs/source/img/kiwipy.svg
   :height: 64px
   :width: 64px
   :alt: kiwiPy
   :target: https://travis-ci.com/github/muhrin/kiwipy

A submission and workflow system that brings together kiwiPy_ to enable robust
task queueing using RabbitMQ_ and mincePy_ to provide database backed storage
of arbitrary python objects.



.. _RabbitMQ: https://www.rabbitmq.com/
.. _kiwiPy: https://github.com/aiidateam/kiwipy
.. _mincePy: https://github.com/muhrin/mincepy